import { Injectable, inject } from '@angular/core';
import { JournalEntry, Npcs, Npc } from 'src/interfaces/interfaces';
import { DataService } from 'src/services/data/data.service';

@Injectable({
  providedIn: 'root',
})
export class TooltipService {
  private dataService: DataService = inject(DataService);

  public tooltipifyEntry(entry: string): any {
    const content = this.replaceIdentifiers(entry);
    const personMatches = entry.match(/(?<=@)\w+/g);
    const uniquePersons = [...new Set(personMatches)];
    // get the descriptions from the data service
    const npcs = this.dataService.npcs;
    const npcArray = Object.keys(npcs)
      .map((key) => npcs[key])
      .flat();
    let npcsDescription: any = {};

    uniquePersons.forEach((person) => {
      const npc = npcArray.find(
        (npc: Npc) => npc.name === person || npc.identifier === person,
      );
      if (npc) {
        // Add it to the npcDescription object
        npcsDescription[person] = npc.shortDescription;
      } else {
        // Add a placeholder to the npcDescription object
        npcsDescription[person] = 'Keine Person mit diesem Name gefunden.';
      }
    });

    const locationsMatches = entry.match(/(?<=#)\w+/g);
    const uniqueLocations = [...new Set(locationsMatches)];
    // get the descriptions from the data service
    const locationArray = this.dataService.places;
    // const locationArray = Object.keys(locations)
    //   .map((key) => locations[key])
    //   .flat();
    let locationsDescription: any = {};

    uniqueLocations.forEach((location) => {
      const loc = locationArray.find(
        (loc) => loc.name === location || loc.identifier === location,
      );
      if (loc) {
        // Add it to the npcDescription object
        locationsDescription[location] = loc.shortDescription;
      } else {
        // Add a placeholder to the npcDescription object
        locationsDescription[location] = 'Kein Ort mit diesem Name gefunden.';
      }
    });

    return {
      content: content,
      identifiers: [...uniquePersons, ...uniqueLocations],
      descriptions: { ...npcsDescription, ...locationsDescription },
    };
  }

  private replaceIdentifiers(content: string): string {
    content = content.replace(/@(\w+)/g, "<span class='$1'></span>");
    content = content.replace(/#(\w+)/g, "<span class='$1'></span>");
    return content;
  }

  // private replaceNpcs(content: string): string {
  //   return content.replace(/@(\w+)/g, "<span class='$1'></span>");
  // }

  // private replaceLocations(content: string): string {
  //   return content.replace(/#(\w+)/g, "<span class='$1'></span>");
  // }
}
